package com.hungraim.ltc.system.controller;

import com.hungraim.ltc.pojo.entity.SysConfig.ChFndAttach;
import com.hungraim.ltc.pojo.vo.system.AttachUpdateVo;
import com.hungraim.ltc.system.config.FileUploadConfig;
import com.hungraim.ltc.system.service.AttachService;
import com.hungraim.ltc.util.FileUtils;
import com.hungraim.ltc.util.Result;
import com.hungraim.ltc.util.ResultCode;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import java.util.List;

@RestController
@RequestMapping("/api.system/resource")
@Slf4j
public class FileUploadController {

    @Autowired
    private FileUploadConfig fileUploadConfig;

    @Autowired
    private AttachService attachService;

    /**
     * 上传文件接口
     *
     * @param file       上传的文件
     * @param uploadType 附件类型 附件类型(1:失能人员附件;2:鉴定任务附件;3:服务方案附件;4:稽核巡查;5:护理机构基金结算申请新增;6:无锡长护保险自评申请;7:失能信息变更附件;
     *                   8:评估结论书;9:参保人员及家属;10:评定人员1;11:评定人员2;12:鉴定机构附件;13:护理机构附件;14:鉴定人员附件;15:护理人员附件 16-护理人员服务项目结束附件，17:建床，18：撤床)
     * @return 返回保存到数据库之后的文件id
     */
    @PostMapping("/uploadFile")
    public Result uploadFile(MultipartFile file, Short uploadType) {
        if (null == uploadType || null == file) {
            return Result.failed(ResultCode.REQUEST_PARAM_ERROR);
        }
        //过滤上传资料类型
        String originalFilename = file.getOriginalFilename();
        //文件类型
        String fileType = originalFilename.substring(file.getOriginalFilename().lastIndexOf("."));
        List<String> fileTypes = fileUploadConfig.getType();
        log.info("支持图片类型：" + fileTypes+",上传的图片类型："+fileType);
        if(!fileTypes.contains(fileType)){
            log.info("上传文件错误");
            return Result.failed(ResultCode.FILE_TYPE_ERROR);
        }
        String realPath = FileUtils.uploadFile(file, fileUploadConfig.getPath());
        log.info("文件上传成功:{}", realPath);
        Long attachId = attachService.saveFileInfo(originalFilename, realPath, uploadType);
        log.info("保存成功，文件id:{}", attachId);
        return Result.success(attachId);
    }


    /**
     * 修改数据库文件表关联数据
     * 参数attachUpdateVo对象中,必须要有ctrlId字段的值以及attachType的值，
     * 方法会以新传入的这个列表作为ctrlId所关联的所有对象，对于旧的关联数据中这次没有传入的attachId数据进行舍弃
     *
     * @param attachUpdateVo 文件对象列表
     * @return 返回执行结果
     */
    @PutMapping("/attachs")
    Result updateAttachs(@RequestBody AttachUpdateVo attachUpdateVo) {
        if (null == attachUpdateVo  || null == attachUpdateVo.getCtrlId() || 0 == attachUpdateVo.getCtrlId() || null == attachUpdateVo.getAttachType() || 0 == attachUpdateVo.getAttachType()) {
            return Result.failed(ResultCode.REQUEST_PARAM_ERROR);
        }
        attachService.updateAttachs(attachUpdateVo);
        return Result.success();
    }

    /**
     * 根据ctrlId和attachType查询其对应的数据列表
     *
     * @param ctrlId     关联id
     * @param attachType 附件类型
     * @return 返回对应的数据列表
     */
    @GetMapping("/attachs")
    Result<List<ChFndAttach>> selectAttachs(Long ctrlId, Short attachType) {
        if (null == ctrlId || 0 == ctrlId || null == attachType) {
            return Result.failed(ResultCode.REQUEST_PARAM_ERROR);
        }
        List<ChFndAttach> chFndAttaches = attachService.selectAttachs(ctrlId, attachType);
        return Result.success(chFndAttaches);
    }
}
